Welcome to elstir

For full documentation visit [elstir.org](https://www.elstir.org).

## Commands

* `elstir new [dir-name]` - Create a new project.
* `elstir serve` - Start the live-reloading docs server.
* `elstir build` - Build the documentation site.
* `elstir help` - Print this help message.

## Project layout

    elstir.yml    # The configuration file.
    docs/
        index.md  # The documentation homepage.
        ...       # Other markdown pages, images and other files.
